require 'spec_helper'
require 'spree_granify/view_helpers'

describe SpreeGranify::ViewHelpers, type: :helper do
  describe 'Granify snippet main actions' do
    let(:page)                   { 'home' }
    let(:site_id)                { 1234 }
    let(:path_to_snippet)        { 'vendor/assets/javascripts/granify_snippet_initializer.js' }
    let(:initial_script)         { javascript_tag("var GRANIFY_SITE_ID = #{site_id};").html_safe }
    let(:order)                  { create :order_with_line_items      }
    let(:wrapped_order)          { order.serialize_cart_to_granify_format  }
    let(:wrapped_complete_order) { order.serialize_order_to_granify_format }

    it 'initialization of granify snippet' do
      allow(helper).to receive(:initial_granify_script).with(path_to_snippet, site_id).and_return(initial_script)
      expect(helper.initial_granify_script(path_to_snippet, site_id)).to eq initial_script
    end

    it 'should track page views' do
      expect(helper.track_page_views(page)).to eq javascript_tag("Granify.trackPageView({page_type: '#{page}'});").html_safe
    end

    it 'should track cart details' do
      expect(helper.track_cart_details(order)).to eq javascript_tag("Granify.trackCart({items: #{wrapped_order}});").html_safe
    end

    it 'should track complete order' do
      expect(helper.track_complete_order(order)).to eq javascript_tag("Granify.trackOrder(#{wrapped_complete_order});").html_safe
    end
  end
end